@@ -1,6 +1,7 @@
 #![allow(clippy::transmute_ptr_to_ref)]
 
 use onig_sys;
+use std::iter::FusedIterator;
 use std::mem::transmute;
 use std::os::raw::{c_int, c_void};
 use std::ptr::null_mut;
@@ -10,6 +11,7 @@ use super::CaptureTreeNode;
 
 /// Represents a set of capture groups found in a search or match.
 #[derive(Debug, Eq, PartialEq)]
+#[repr(transparent)]
 pub struct Region {
     pub(crate) raw: onig_sys::OnigRegion,
 }
@@ -251,6 +253,10 @@ impl<'a> Iterator for RegionIter<'a> {
     }
 }
 
+impl<'a> FusedIterator for RegionIter<'a> {}
+
+impl<'a> ExactSizeIterator for RegionIter<'a> {}
+
 #[cfg(test)]
 mod tests {
     use super::super::{Regex, SearchOptions};
