@@ -1,7 +1,7 @@
 #![allow(clippy::transmute_ptr_to_ref)]
 
 use onig_sys;
-use std::iter::Iterator;
+use std::iter::FusedIterator;
 use std::mem::transmute;
 use std::ops::Index;
 
@@ -10,8 +10,8 @@ use std::ops::Index;
 /// Represents a single node in the capture tree. Can be queried for
 /// information about the given capture and any child-captures that
 /// took place.
-#[repr(C)]
 #[derive(Debug)]
+#[repr(transparent)]
 pub struct CaptureTreeNode {
     raw: onig_sys::OnigCaptureTreeNode,
 }
@@ -54,7 +54,7 @@ impl Index<usize> for CaptureTreeNode {
     }
 }
 
-/// Caputres iterator
+/// Captures iterator
 #[derive(Debug)]
 pub struct CaptureTreeNodeIter<'t> {
     idx: usize,
@@ -77,8 +77,16 @@ impl<'t> Iterator for CaptureTreeNodeIter<'t> {
         let size = self.node.len();
         (size, Some(size))
     }
+
+    fn count(self) -> usize {
+        self.node.len()
+    }
 }
 
+impl<'t> FusedIterator for CaptureTreeNodeIter<'t> {}
+
+impl<'t> ExactSizeIterator for CaptureTreeNodeIter<'t> {}
+
 #[cfg(test)]
 mod tests {
     use super::super::*;
